@@ -11,6 +11,7 @@ import (
 
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/internal/config"
+	"gitlab.com/gitlab-org/cli/test"
 )
 
 func Test_groupGraphQLVariables(t *testing.T) {
@@ -96,7 +97,7 @@ hosts:
     username: monalisa
     token: OTOKEN
 `, "")()
-	t.Setenv("GITLAB_TOKEN", "")
+	test.ClearEnvironmentVariables(t)
 
 	api.SetUserAgent("v1.2.3", "darwin", "arm64")
 	versionString := "glab/v1.2.3 (darwin, arm64)"
@@ -365,7 +366,7 @@ func Test_addQuery(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			if got, err := parseQuery(tt.args.path, tt.args.params); got != tt.want {
 				if err != nil {
-					t.Errorf(err.Error())
+					t.Error(err.Error())
 				}
 				t.Errorf("parseQuery() = %v, want %v", got, tt.want)
 			}
