@@ -13,9 +13,10 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
 	"github.com/AlecAivazis/survey/v2"
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"github.com/zalando/go-keyring"
+
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/config"
@@ -32,6 +33,10 @@ type LoginOptions struct {
 	Hostname string
 	Token    string
 
+	ApiHost     string
+	ApiProtocol string
+	GitProtocol string
+
 	UseKeyring bool
 }
 
@@ -48,27 +53,36 @@ func NewCmdLogin(f *cmdutils.Factory) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "login",
 		Args:  cobra.ExactArgs(0),
-		Short: "Authenticate with a GitLab instance",
+		Short: "Authenticate with a GitLab instance.",
 		Long: heredoc.Docf(`
 			Authenticate with a GitLab instance.
 			You can pass in a token on standard input by using %[1]s--stdin%[1]s.
 			The minimum required scopes for the token are: %[1]sapi%[1]s, %[1]swrite_repository%[1]s.
+			Configuration and credentials are stored in the global configuration file (Default: %[1]s~/.config/glab-cli/config.yml%[1]s)
 		`, "`"),
 		Example: heredoc.Docf(`
-			# start interactive setup
+			# Start interactive setup
 			$ glab auth login
-			# authenticate against %[1]sgitlab.com%[1]s by reading the token from a file
+
+			# Authenticate against %[1]sgitlab.com%[1]s by reading the token from a file
 			$ glab auth login --stdin < myaccesstoken.txt
-			# authenticate with a self-hosted GitLab instance
+
+			# Authenticate with a self-hosted GitLab instance
 			$ glab auth login --hostname salsa.debian.org
+
+			# Non-interactive setup
+			$ glab auth login --hostname gitlab.example.org --token glpat-xxx --api-host gitlab.example.org:3443 --api-protocol https --git-protocol ssh
+
+			# Non-interactive setup reading token from a file
+			$ glab auth login --hostname gitlab.example.org --api-host gitlab.example.org:3443 --api-protocol https --git-protocol ssh  --stdin < myaccesstoken.txt
 		`, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if !opts.IO.PromptEnabled() && !tokenStdin && opts.Token == "" {
-				return &cmdutils.FlagError{Err: errors.New("--stdin or --token required when not running interactively")}
+				return &cmdutils.FlagError{Err: errors.New("'--stdin' or '--token' required when not running interactively.")}
 			}
 
 			if opts.Token != "" && tokenStdin {
-				return &cmdutils.FlagError{Err: errors.New("specify one of --token or --stdin. You cannot use both flags at the same time")}
+				return &cmdutils.FlagError{Err: errors.New("specify one of '--token' or '--stdin'. You cannot use both flags at the same time.")}
 			}
 
 			if tokenStdin {
@@ -86,29 +100,38 @@ func NewCmdLogin(f *cmdutils.Factory) *cobra.Command {
 
 			if cmd.Flags().Changed("hostname") {
 				if err := hostnameValidator(opts.Hostname); err != nil {
-					return &cmdutils.FlagError{Err: fmt.Errorf("error parsing --hostname: %w", err)}
+					return &cmdutils.FlagError{Err: fmt.Errorf("error parsing '--hostname': %w", err)}
 				}
 			}
 
-			if !opts.Interactive {
-				if opts.Hostname == "" {
-					opts.Hostname = glinstance.Default()
-				}
+			if !opts.Interactive && opts.Hostname == "" {
+				opts.Hostname = glinstance.Default()
 			}
 
-			return loginRun()
+			if opts.Interactive && (opts.ApiHost != "" || opts.ApiProtocol != "" || opts.GitProtocol != "") {
+				return &cmdutils.FlagError{Err: errors.New("api-host, api-protocol, and git-protocol can only be used in non-interactive mode.")}
+			}
+
+			if err := loginRun(opts); err != nil {
+				return cmdutils.WrapError(err, "Could not sign in!")
+			}
+
+			return nil
 		},
 	}
 
-	cmd.Flags().StringVarP(&opts.Hostname, "hostname", "h", "", "The hostname of the GitLab instance to authenticate with")
-	cmd.Flags().StringVarP(&opts.Token, "token", "t", "", "Your GitLab access token")
-	cmd.Flags().BoolVar(&tokenStdin, "stdin", false, "Read token from standard input")
-	cmd.Flags().BoolVar(&opts.UseKeyring, "use-keyring", false, "Store token in your operating system's keyring")
+	cmd.Flags().StringVarP(&opts.Hostname, "hostname", "h", "", "The hostname of the GitLab instance to authenticate with.")
+	cmd.Flags().StringVarP(&opts.Token, "token", "t", "", "Your GitLab access token.")
+	cmd.Flags().BoolVar(&tokenStdin, "stdin", false, "Read token from standard input.")
+	cmd.Flags().BoolVar(&opts.UseKeyring, "use-keyring", false, "Store token in your operating system's keyring.")
+	cmd.Flags().StringVarP(&opts.ApiHost, "api-host", "a", "", "API host url.")
+	cmd.Flags().StringVarP(&opts.ApiProtocol, "api-protocol", "p", "", "API protocol: https, http")
+	cmd.Flags().StringVarP(&opts.GitProtocol, "git-protocol", "g", "", "Git protocol: ssh, https, http")
 
 	return cmd
 }
 
-func loginRun() error {
+func loginRun(opts *LoginOptions) error {
 	c := opts.IO.Color()
 	cfg, err := opts.Config()
 	if err != nil {
@@ -117,7 +140,7 @@ func loginRun() error {
 
 	if opts.Token != "" {
 		if opts.Hostname == "" {
-			return errors.New("empty hostname would leak oauth_token")
+			return errors.New("empty hostname would leak `oauth_token`")
 		}
 
 		if opts.UseKeyring {
@@ -129,7 +152,27 @@ func loginRun() error {
 			}
 
 			if token := config.GetFromEnv("token"); token != "" {
-				fmt.Fprintf(opts.IO.StdErr, "%s a GITLAB_TOKEN or OAUTH_TOKEN environment variable is set. If you don't want to use it for glab, unset it.\n", c.Yellow("WARNING:"))
+				fmt.Fprintf(opts.IO.StdErr, "%s One of %s environment variables is set. If you don't want to use it for glab, unset it.\n", c.Yellow("WARNING:"), strings.Join(config.EnvKeyEquivalence("token"), ", "))
+			}
+			if opts.ApiHost != "" {
+				err = cfg.Set(opts.Hostname, "api_host", opts.ApiHost)
+				if err != nil {
+					return err
+				}
+			}
+
+			if opts.ApiProtocol != "" {
+				err = cfg.Set(opts.Hostname, "api_protocol", opts.ApiProtocol)
+				if err != nil {
+					return err
+				}
+			}
+
+			if opts.GitProtocol != "" {
+				err = cfg.Set(opts.Hostname, "git_protocol", opts.GitProtocol)
+				if err != nil {
+					return err
+				}
 			}
 
 			return cfg.Write()
@@ -139,6 +182,11 @@ func loginRun() error {
 
 	hostname := opts.Hostname
 	apiHostname := opts.Hostname
+
+	if opts.ApiHost != "" {
+		apiHostname = opts.ApiHost
+	}
+
 	defaultHostname := glinstance.OverridableDefault()
 	isSelfHosted := false
 
@@ -168,19 +216,21 @@ func loginRun() error {
 			}
 			err = survey.AskOne(&survey.Input{
 				Message: "API hostname:",
-				Help:    "For instances with different hostname for the API endpoint",
+				Help:    "For instances with different hostname for the API endpoint.",
 				Default: hostname,
 			}, &apiHostname, survey.WithValidator(hostnameValidator))
 			if err != nil {
 				return fmt.Errorf("could not prompt: %w", err)
 			}
 		}
+	} else {
+		isSelfHosted = glinstance.IsSelfHosted(hostname)
 	}
 
 	fmt.Fprintf(opts.IO.StdErr, "- Logging into %s\n", hostname)
 
 	if token := config.GetFromEnv("token"); token != "" {
-		fmt.Fprintf(opts.IO.StdErr, "%s a GITLAB_TOKEN or OAUTH_TOKEN environment variable is set. If you don't want to use it for glab, unset it.\n", c.Yellow("WARNING:"))
+		fmt.Fprintf(opts.IO.StdErr, "%s One of %s environment variables is set. If you don't want to use it for glab, unset it.\n", c.Yellow("WARNING:"), strings.Join(config.EnvKeyEquivalence("token"), ", "))
 	}
 	existingToken, _, _ := cfg.GetWithSource(hostname, "token", false)
 
@@ -211,36 +261,24 @@ func loginRun() error {
 		}
 	}
 
-	loginType := 0
+	var loginType string
 
 	if opts.Interactive {
-		if isSelfHosted {
-			err := survey.AskOne(&survey.Select{
-				Message: "How would you like to login?",
-				Options: []string{
-					"Token",
-				},
-			}, &loginType)
-			if err != nil {
-				return fmt.Errorf("could not get login type: %w", err)
-			}
-		} else {
-			err := survey.AskOne(&survey.Select{
-				Message: "How would you like to login?",
-				Options: []string{
-					"Token",
-					"Web",
-				},
-			}, &loginType)
-			if err != nil {
-				return fmt.Errorf("could not get login type: %w", err)
-			}
+		err := survey.AskOne(&survey.Select{
+			Message: "How would you like to sign in?",
+			Options: []string{
+				"Token",
+				"Web",
+			},
+		}, &loginType)
+		if err != nil {
+			return fmt.Errorf("could not get login type: %w", err)
 		}
 	}
 
 	var token string
-	if loginType == 0 {
-		token, err = showTokenPrompt(hostname)
+	if strings.EqualFold(loginType, "token") {
+		token, err = showTokenPrompt(opts.IO, hostname)
 		if err != nil {
 			return err
 		}
@@ -264,7 +302,7 @@ func loginRun() error {
 	}
 
 	if hostname == "" {
-		return errors.New("empty hostname would leak token")
+		return errors.New("empty hostname would leak the token")
 	}
 
 	err = cfg.Set(hostname, "api_host", apiHostname)
@@ -283,7 +321,7 @@ func loginRun() error {
 
 	if opts.Interactive {
 		err = survey.AskOne(&survey.Select{
-			Message: "Choose default git protocol",
+			Message: "Choose default Git protocol:",
 			Options: []string{
 				"SSH",
 				"HTTPS",
@@ -304,7 +342,7 @@ func loginRun() error {
 
 		if isSelfHosted {
 			err = survey.AskOne(&survey.Select{
-				Message: "Choose host API protocol",
+				Message: "Choose host API protocol:",
 				Options: []string{
 					"HTTPS",
 					"HTTP",
@@ -324,7 +362,7 @@ func loginRun() error {
 			return err
 		}
 
-		fmt.Fprintf(opts.IO.StdErr, "%s Configured git protocol\n", c.GreenCheck())
+		fmt.Fprintf(opts.IO.StdErr, "%s Configured Git protocol.\n", c.GreenCheck())
 
 		fmt.Fprintf(opts.IO.StdErr, "- glab config set -h %s api_protocol %s\n", hostname, apiProtocol)
 		err = cfg.Set(hostname, "api_protocol", apiProtocol)
@@ -332,7 +370,7 @@ func loginRun() error {
 			return err
 		}
 
-		fmt.Fprintf(opts.IO.StdErr, "%s Configured API protocol\n", c.GreenCheck())
+		fmt.Fprintf(opts.IO.StdErr, "%s Configured API protocol.\n", c.GreenCheck())
 	}
 	apiClient, err := cmdutils.LabClientFunc(hostname, cfg, false)
 	if err != nil {
@@ -341,7 +379,7 @@ func loginRun() error {
 
 	user, err := api.CurrentUser(apiClient)
 	if err != nil {
-		return fmt.Errorf("error using api: %w", err)
+		return fmt.Errorf("error using API: %w", err)
 	}
 	username := user.Username
 
@@ -363,6 +401,7 @@ func loginRun() error {
 	}
 
 	fmt.Fprintf(opts.IO.StdErr, "%s Logged in as %s\n", c.GreenCheck(), c.Bold(username))
+	fmt.Fprintf(opts.IO.StdErr, "%s Configuration saved to %s/%s\n", c.GreenCheck(), config.ConfigDir(), config.ConfigFile())
 
 	return nil
 }
@@ -370,7 +409,7 @@ func loginRun() error {
 func hostnameValidator(v interface{}) error {
 	val := fmt.Sprint(v)
 	if len(strings.TrimSpace(val)) < 1 {
-		return errors.New("a value is required")
+		return errors.New("a value is required.")
 	}
 	re := regexp.MustCompile(`^(([a-z0-9]|[a-z0-9][a-z0-9\-]*[a-z0-9])\.)*([a-z0-9]|[a-z0-9][a-z0-9\-]*[a-z0-9])(:[0-9]+)?(/[a-z0-9]*)*$`)
 	if !re.MatchString(val) {
@@ -385,13 +424,13 @@ func getAccessTokenTip(hostname string) string {
 		glHostname = glinstance.OverridableDefault()
 	}
 	return fmt.Sprintf(`
-	Tip: you can generate a Personal Access Token here https://%s/-/profile/personal_access_tokens?scopes=api,write_repository
+	Tip: generate a personal access token at https://%s/-/user_settings/personal_access_tokens?scopes=api,write_repository.
 	The minimum required scopes are 'api' and 'write_repository'.`, glHostname)
 }
 
-func showTokenPrompt(hostname string) (string, error) {
-	fmt.Fprintln(opts.IO.StdErr)
-	fmt.Fprintln(opts.IO.StdErr, heredoc.Doc(getAccessTokenTip(hostname)))
+func showTokenPrompt(io *iostreams.IOStreams, hostname string) (string, error) {
+	fmt.Fprintln(io.StdErr)
+	fmt.Fprintln(io.StdErr, heredoc.Doc(getAccessTokenTip(hostname)))
 
 	var token string
 	err := survey.AskOne(&survey.Password{
