@@ -9,6 +9,7 @@ import (
 	"sync"
 	"time"
 
+	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/git"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
@@ -100,16 +101,16 @@ func runTrace(ctx context.Context, apiClient *gitlab.Client, w io.Writer, pid in
 		}
 		switch job.Status {
 		case "pending":
-			fmt.Fprintf(w, "%s is pending... waiting for job to start\n", job.Name)
+			fmt.Fprintf(w, "%s is pending... waiting for job to start.\n", job.Name)
 			continue
 		case "manual":
-			fmt.Fprintf(w, "Manual job %s not started, waiting for job to start\n", job.Name)
+			fmt.Fprintf(w, "Manual job %s not started, waiting for job to start.\n", job.Name)
 			continue
 		case "skipped":
-			fmt.Fprintf(w, "%s has been skipped\n", job.Name)
+			fmt.Fprintf(w, "%s has been skipped.\n", job.Name)
 		}
 		once.Do(func() {
-			fmt.Fprintf(w, "Showing logs for %s job #%d\n", job.Name, job.ID)
+			fmt.Fprintf(w, "Showing logs for %s job #%d.\n", job.Name, job.ID)
 		})
 		trace, _, err := apiClient.Jobs.GetTraceFile(pid, jobId)
 		if err != nil || trace == nil {
@@ -159,7 +160,7 @@ func GetJobId(inputs *JobInputs, opts *JobOptions) (int, error) {
 		}
 	}
 
-	return 0, fmt.Errorf("pipeline %d contains no jobs", pipelineId)
+	return 0, fmt.Errorf("pipeline %d contains no jobs.", pipelineId)
 }
 
 func getPipelineId(inputs *JobInputs, opts *JobOptions) (int, error) {
@@ -179,6 +180,27 @@ func getPipelineId(inputs *JobInputs, opts *JobOptions) (int, error) {
 	return pipeline.ID, err
 }
 
+func GetDefaultBranch(f *cmdutils.Factory) string {
+	repo, err := f.BaseRepo()
+	if err != nil {
+		return "master"
+	}
+
+	remotes, err := f.Remotes()
+	if err != nil {
+		return "master"
+	}
+
+	repoRemote, err := remotes.FindByRepo(repo.RepoOwner(), repo.RepoName())
+	if err != nil {
+		return "master"
+	}
+
+	branch, _ := git.GetDefaultBranch(repoRemote.Name)
+
+	return branch
+}
+
 func getBranch(branch string, opts *JobOptions) (string, error) {
 	if branch != "" {
 		return branch, nil
@@ -209,21 +231,30 @@ func getJobIdInteractive(inputs *JobInputs, opts *JobOptions) (int, error) {
 	var selectedJob string
 
 	for _, job := range jobs {
-		jobOptions = append(jobOptions, fmt.Sprintf("%s (%d) - %s", job.Name, job.ID, job.Status))
+		if inputs.SelectionPredicate == nil || inputs.SelectionPredicate(job) {
+			jobOptions = append(jobOptions, fmt.Sprintf("%s (%d) - %s", job.Name, job.ID, job.Status))
+		}
+	}
+
+	messagePrompt := inputs.SelectionPrompt
+	if messagePrompt == "" {
+		messagePrompt = "Select pipeline job to trace:"
 	}
 
 	promptOpts := &survey.Select{
-		Message: "Select pipeline job to trace:",
+		Message: messagePrompt,
 		Options: jobOptions,
 	}
+	if len(jobOptions) > 0 {
 
-	err = prompt.AskOne(promptOpts, &selectedJob)
-	if err != nil {
-		if errors.Is(err, terminal.InterruptErr) {
-			return 0, nil
+		err = prompt.AskOne(promptOpts, &selectedJob)
+		if err != nil {
+			if errors.Is(err, terminal.InterruptErr) {
+				return 0, nil
+			}
+
+			return 0, err
 		}
-
-		return 0, err
 	}
 
 	if selectedJob != "" {
@@ -231,43 +262,45 @@ func getJobIdInteractive(inputs *JobInputs, opts *JobOptions) (int, error) {
 		m := re.FindAllStringSubmatch(selectedJob, -1)
 		return utils.StringToInt(m[0][1]), nil
 	} else if len(jobs) > 0 {
-		return jobs[0].ID, nil
-	} else {
-		pipeline, err := api.GetPipeline(opts.ApiClient, pipelineId, nil, opts.Repo.FullName())
-		if err != nil {
-			return 0, err
-		}
-		// use commit statuses to show external jobs
-		cs, err := api.GetCommitStatuses(opts.ApiClient, opts.Repo.FullName(), pipeline.SHA)
-		if err != nil {
-			return 0, nil
-		}
-
-		c := opts.IO.Color()
-
-		fmt.Fprint(opts.IO.StdOut, "Getting external jobs...")
-		for _, status := range cs {
-			var s string
-
-			switch status.Status {
-			case "success":
-				s = c.Green(status.Status)
-			case "error":
-				s = c.Red(status.Status)
-			default:
-				s = c.Gray(status.Status)
-			}
-			fmt.Fprintf(opts.IO.StdOut, "(%s) %s\nURL: %s\n\n", s, c.Bold(status.Name), c.Gray(status.TargetURL))
-		}
-
 		return 0, nil
 	}
+
+	pipeline, err := api.GetPipeline(opts.ApiClient, pipelineId, nil, opts.Repo.FullName())
+	if err != nil {
+		return 0, err
+	}
+	// use commit statuses to show external jobs
+	cs, err := api.GetCommitStatuses(opts.ApiClient, opts.Repo.FullName(), pipeline.SHA)
+	if err != nil {
+		return 0, nil
+	}
+
+	c := opts.IO.Color()
+
+	fmt.Fprint(opts.IO.StdOut, "Getting external jobs...\n")
+	for _, status := range cs {
+		var s string
+
+		switch status.Status {
+		case "success":
+			s = c.Green(status.Status)
+		case "error":
+			s = c.Red(status.Status)
+		default:
+			s = c.Gray(status.Status)
+		}
+		fmt.Fprintf(opts.IO.StdOut, "(%s) %s\nURL: %s\n\n", s, c.Bold(status.Name), c.Gray(status.TargetURL))
+	}
+
+	return 0, nil
 }
 
 type JobInputs struct {
-	JobName    string
-	Branch     string
-	PipelineId int
+	JobName            string
+	Branch             string
+	PipelineId         int
+	SelectionPrompt    string
+	SelectionPredicate func(s *gitlab.Job) bool
 }
 
 type JobOptions struct {
@@ -282,6 +315,9 @@ func TraceJob(inputs *JobInputs, opts *JobOptions) error {
 		fmt.Fprintln(opts.IO.StdErr, "invalid job ID:", inputs.JobName)
 		return err
 	}
+	if jobID == 0 {
+		return nil
+	}
 	fmt.Fprintln(opts.IO.StdOut)
 	return runTrace(context.Background(), opts.ApiClient, opts.IO.StdOut, opts.Repo.FullName(), jobID)
 }
