@@ -69,8 +69,8 @@ func TestMrApprove(t *testing.T) {
 		out := output.String()
 
 		assert.Equal(t, heredoc.Doc(`
-		✓ Pipeline Succeeded
-		✓ Merged
+		✓ Pipeline succeeded.
+		✓ Merged!
 		https://gitlab.com/OWNER/REPO/-/merge_requests/123
 		`), out)
 		assert.Empty(t, output.Stderr())
