@@ -20,8 +20,8 @@ type CreateOpts struct {
 	Description     string
 	DisplayFilename string
 	Visibility      string
+	Personal        bool
 
-	ForUser  bool
 	FilePath string
 
 	IO       *iostreams.IOStreams
@@ -33,17 +33,28 @@ func (opts CreateOpts) isSnippetFromFile() bool {
 	return opts.FilePath != ""
 }
 
+func hasStdIn() bool {
+	fi, err := os.Stdin.Stat()
+	if err != nil {
+		return false
+	}
+
+	return fi.Size() > 0
+}
+
 func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 	opts := &CreateOpts{}
 	snippetCreateCmd := &cobra.Command{
 		Use:     "create [path]",
-		Short:   `Create new snippet`,
+		Short:   `Create a new snippet.`,
 		Long:    ``,
 		Aliases: []string{"new"},
 		Example: heredoc.Doc(`
-			glab snippet create script.py --title "Title of the snippet" 
+			glab snippet create script.py --title "Title of the snippet"
 			echo "package main" | glab snippet new --title "Title of the snippet" --filename "main.go"
 			glab snippet create main.go -t Title -f "different.go" -d Description
+			glab snippet create main.go -t Title -f "different.go" -d Description --filename different.go
+			glab snippet create script.py --personal --title "Personal snippet"
 		`),
 		PreRunE: func(cmd *cobra.Command, args []string) error {
 			opts.IO = f.IO
@@ -56,7 +67,11 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			}
 			if len(args) == 0 {
 				if opts.DisplayFilename == "" {
-					return &cmdutils.FlagError{Err: errors.New("if path is not provided filename is required")}
+					return &cmdutils.FlagError{Err: errors.New("if 'path' is not provided, 'filename' and stdin are required")}
+				} else {
+					if !hasStdIn() {
+						return errors.New("stdin required if no 'path' is provided")
+					}
 				}
 			} else {
 				if opts.DisplayFilename == "" {
@@ -72,19 +87,24 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			if err != nil {
 				return err
 			}
-			repo, err := opts.BaseRepo()
-			if err != nil {
-				return err
-			}
+			if opts.Personal {
+				return runCreate(client, nil, opts)
+			} else {
+				repo, err := opts.BaseRepo()
+				if err != nil {
+					return err
+				}
+				return runCreate(client, repo, opts)
 
-			return runCreate(client, repo, opts)
+			}
 		},
 	}
 
-	snippetCreateCmd.Flags().StringVarP(&opts.Title, "title", "t", "", "Title of the snippet")
-	snippetCreateCmd.Flags().StringVarP(&opts.DisplayFilename, "filename", "f", "", "Filename of the snippet in GitLab")
-	snippetCreateCmd.Flags().StringVarP(&opts.Description, "description", "d", "", "Description of the snippet")
-	snippetCreateCmd.Flags().StringVarP(&opts.Visibility, "visibility", "v", "private", "Limit by visibility {public, internal, or private}")
+	snippetCreateCmd.Flags().StringVarP(&opts.Title, "title", "t", "", "Title of the snippet.")
+	snippetCreateCmd.Flags().StringVarP(&opts.DisplayFilename, "filename", "f", "", "Filename of the snippet in GitLab.")
+	snippetCreateCmd.Flags().StringVarP(&opts.Description, "description", "d", "", "Description of the snippet.")
+	snippetCreateCmd.Flags().StringVarP(&opts.Visibility, "visibility", "v", "private", "Limit by visibility: 'public', 'internal', or 'private'")
+	snippetCreateCmd.Flags().BoolVarP(&opts.Personal, "personal", "p", false, "Create a personal snippet.")
 
 	return snippetCreateCmd
 }
@@ -94,16 +114,28 @@ func runCreate(client *gitlab.Client, repo glrepo.Interface, opts *CreateOpts) e
 	if err != nil {
 		return err
 	}
-	fmt.Fprintln(opts.IO.StdErr, "- Creating snippet in", repo.FullName())
-	snippet, err := api.CreateProjectSnippet(client, repo.FullName(), &gitlab.CreateProjectSnippetOptions{
-		Title:       &opts.Title,
-		Description: &opts.Description,
-		Content:     gitlab.Ptr(string(content)),
-		FileName:    &opts.DisplayFilename,
-		Visibility:  gitlab.Ptr(gitlab.VisibilityValue(opts.Visibility)),
-	})
+	var snippet *gitlab.Snippet
+	if opts.Personal {
+		fmt.Fprintln(opts.IO.StdErr, "- Creating snippet in personal space")
+		snippet, err = api.CreateSnippet(client, &gitlab.CreateSnippetOptions{
+			Title:       &opts.Title,
+			Description: &opts.Description,
+			Content:     gitlab.Ptr(string(content)),
+			FileName:    &opts.DisplayFilename,
+			Visibility:  gitlab.Ptr(gitlab.VisibilityValue(opts.Visibility)),
+		})
+	} else {
+		fmt.Fprintln(opts.IO.StdErr, "- Creating snippet in", repo.FullName())
+		snippet, err = api.CreateProjectSnippet(client, repo.FullName(), &gitlab.CreateProjectSnippetOptions{
+			Title:       &opts.Title,
+			Description: &opts.Description,
+			Content:     gitlab.Ptr(string(content)),
+			FileName:    &opts.DisplayFilename,
+			Visibility:  gitlab.Ptr(gitlab.VisibilityValue(opts.Visibility)),
+		})
+	}
 	if err != nil {
-		return fmt.Errorf("failed to create snippet. %w", err)
+		return fmt.Errorf("failed to create snippet: %w", err)
 	}
 	snippetID := opts.IO.Color().Green(fmt.Sprintf("$%d", snippet.ID))
 	if opts.IO.IsaTTY {
@@ -120,8 +152,8 @@ func runCreate(client *gitlab.Client, repo glrepo.Interface, opts *CreateOpts) e
 //	Doesn't support it yet.
 //
 //	See for the API reference: https://docs.gitlab.com/ee/api/snippets.html#create-new-snippet
-//	See for the library docs : https://pkg.go.dev/github.com/xanzy/go-gitlab#CreateSnippetOptions
-//	See for GitHub issue     : https://github.com/xanzy/go-gitlab/issues/1372
+//	See for the library docs: https://pkg.go.dev/github.com/xanzy/go-gitlab#CreateSnippetOptions
+//	See for GitHub issue: https://github.com/xanzy/go-gitlab/issues/1372
 func readSnippetsContent(opts *CreateOpts) (string, error) {
 	if opts.isSnippetFromFile() {
 		return readFromFile(opts.FilePath)
