@@ -2,10 +2,9 @@ package get
 
 import (
 	"encoding/json"
-	"errors"
 	"fmt"
 
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"github.com/xanzy/go-gitlab"
 	"gitlab.com/gitlab-org/cli/api"
@@ -34,11 +33,11 @@ func NewCmdSet(f *cmdutils.Factory, runE func(opts *GetOps) error) *cobra.Comman
 
 	cmd := &cobra.Command{
 		Use:   "get <key>",
-		Short: "get a project or group variable",
+		Short: "Get a variable for a project or group.",
 		Args:  cobra.RangeArgs(1, 1),
 		Example: heredoc.Doc(`
 			glab variable get VAR_KEY
-            glab variable get -g GROUP VAR_KEY
+			glab variable get -g GROUP VAR_KEY
 			glab variable get -s SCOPE VAR_KEY
 		`),
 		RunE: func(cmd *cobra.Command, args []string) (err error) {
@@ -52,11 +51,6 @@ func NewCmdSet(f *cmdutils.Factory, runE func(opts *GetOps) error) *cobra.Comman
 				return
 			}
 
-			if cmd.Flags().Changed("scope") && opts.Group != "" {
-				err = cmdutils.FlagError{Err: errors.New("Scope is not required for group variables.")}
-				return
-			}
-
 			if runE != nil {
 				err = runE(opts)
 				return
@@ -66,9 +60,9 @@ func NewCmdSet(f *cmdutils.Factory, runE func(opts *GetOps) error) *cobra.Comman
 		},
 	}
 
-	cmd.Flags().StringVarP(&opts.Scope, "scope", "s", "*", "The environment_scope of the variable. All (*), or specific environments.")
-	cmd.Flags().StringVarP(&opts.Group, "group", "g", "", "Get variable for a group")
-	cmd.Flags().StringVarP(&opts.OutputFormat, "output", "F", "text", "Format output as: text, json")
+	cmd.Flags().StringVarP(&opts.Scope, "scope", "s", "*", "The environment_scope of the variable. Values: all (*), or specific environments.")
+	cmd.Flags().StringVarP(&opts.Group, "group", "g", "", "Get variable for a group.")
+	cmd.Flags().StringVarP(&opts.OutputFormat, "output", "F", "text", "Format output as: text, json.")
 	return cmd
 }
 
@@ -81,7 +75,7 @@ func getRun(opts *GetOps) error {
 	var variableValue string
 
 	if opts.Group != "" {
-		variable, err := api.GetGroupVariable(httpClient, opts.Group, opts.Key, nil)
+		variable, err := api.GetGroupVariable(httpClient, opts.Group, opts.Key, opts.Scope)
 		if err != nil {
 			return err
 		}
