@@ -195,7 +195,7 @@ func Test_setRun_project(t *testing.T) {
 
 	err := setRun(opts)
 	assert.NoError(t, err)
-	assert.Equal(t, stdout.String(), "✓ Created variable NEW_VARIABLE for owner/repo with scope *\n")
+	assert.Equal(t, stdout.String(), "✓ Created variable NEW_VARIABLE for owner/repo with scope *.\n")
 }
 
 func Test_setRun_group(t *testing.T) {
@@ -235,5 +235,5 @@ func Test_setRun_group(t *testing.T) {
 
 	err := setRun(opts)
 	assert.NoError(t, err)
-	assert.Equal(t, stdout.String(), "✓ Created variable NEW_VARIABLE for group mygroup\n")
+	assert.Equal(t, stdout.String(), "✓ Created variable NEW_VARIABLE for group mygroup.\n")
 }
