@@ -3,7 +3,7 @@ package variableutils
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
+	"github.com/stretchr/testify/assert"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 )
 
